Trait Source 

pub trait Source {
    type Error;

    // Required method
    fn pipe_data<IN, R>(
        &mut self,
        request: &mut Request<IN, R>,
    ) -> Result<(), Self::Error>
       where IN: ArrayLength<u8>,
             R: ResponseHandler;
}
A source of data for the HTTP response

Required Associated Types

Required Methods

fn pipe_data<IN, R>( &mut self, request: &mut Request<IN, R>, ) -> Result<(), Self::Error>

This will block, and forward data from this source to the request, until the request is completed or a read error occurred.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'tcp, T> Source for TcpSocketSinkSource<'tcp, T>
where T: TcpStack,